@@ -1,7 +1,15 @@
 library(data.table)
 library(testthat)
 
-test_that("warning for only one N", {
+test_that("error when user provided duplicate N", {
+  expect_error({
+    atime::atime(N=c(1,2,2,3,9,9,9), num=numeric(N))
+  },
+  "please remove duplicate values from N: 2, 9",
+  fixed=TRUE)
+})
+
+test_that("warning when result contains only one N", {
   expect_warning({
     seconds.limit <- 0.001
     atime.list <- atime::atime(
@@ -368,11 +376,12 @@ if(requireNamespace("nc")){
 
 if(requireNamespace("ggplot2"))test_that("references for non-NA unit, with NA unit",{
   atime.list <- atime::atime(
+    N=2^seq(0,4),
     missing=data.frame(my_unit=NA),
     constant=data.frame(my_unit=1),
     linear=data.frame(my_unit=N),
     quadratic=data.frame(my_unit=N^2),
-    seconds.limit=0.001,
+    seconds.limit=Inf,
     result=TRUE)
   (atab <- table(atime.list$meas$expr.name))
   ref.list <- atime::references_best(atime.list)
